@@ -22,6 +22,11 @@ import itertools
 import re
 import logging
 
+try:
+    from collections.abc import MutableMapping  # Python 3
+except ImportError:
+    from collections import MutableMapping  # Python 2
+
 
 LOGGER = logging.getLogger(__name__)
 
@@ -150,7 +155,7 @@ class GameNode(object):
 
         Do not call this on the root node.
         """
-        return self.parent.board().san(self.move, chess960=chess960)
+        return self.parent.board().uci(self.move, chess960=chess960)
 
     def root(self):
         """Gets the root node, i.e. the game."""
@@ -507,7 +512,7 @@ class Game(GameNode):
         return cls(headers={})
 
 
-class Headers(collections.MutableMapping):
+class Headers(MutableMapping):
     def __init__(self, data=None, **kwargs):
         self._tag_roster = {}
         self._others = {}
